==> jc-1.4.0.tar.gz: java/io/NotActiveException.h <==
// public class java.io.NotActiveException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class a14ff42e403f5063 java_io_NotActiveException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_NotActiveException_H_
#define _JC_java_io_NotActiveException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_NotActiveException$sub_refs	_jc_java_io_NotActiveException$sub_refs;
typedef struct _jc_java_io_NotActiveException$sub_nonrefs	_jc_java_io_NotActiveException$sub_nonrefs;
typedef struct _jc_java_io_NotActiveException$refs	_jc_java_io_NotActiveException$refs;
typedef struct _jc_java_io_NotActiveException$nonrefs	_jc_java_io_NotActiveException$nonrefs;
typedef struct _jc_java_io_NotActiveException$object	_jc_java_io_NotActiveException$object;

typedef struct _jc_java_io_NotActiveException$fields_struct	_jc_java_io_NotActiveException$fields_struct;
typedef const struct _jc_java_io_NotActiveException$vmethods	_jc_java_io_NotActiveException$vmethods;
typedef const struct _jc_java_io_NotActiveException$vtable	_jc_java_io_NotActiveException$vtable;
typedef const struct _jc_java_io_NotActiveException$vtype	_jc_java_io_NotActiveException$vtype;

// Class fields structure
struct _jc_java_io_NotActiveException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_NotActiveException$fields_struct _jc_java_io_NotActiveException$class_fields;

// Constructors
extern void _jc_java_io_NotActiveException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_NotActiveException$object *);
extern void _jc_java_io_NotActiveException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_NotActiveException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_io_NotActiveException$vmethods {
};

// Vtable
struct _jc_java_io_NotActiveException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_NotActiveException$vmethods	java_io_NotActiveException;
};

// Vtype
struct _jc_java_io_NotActiveException$vtype {
	_jc_type			type;
	_jc_java_io_NotActiveException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_NotActiveException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_NotActiveException$refs {
    _jc_java_io_NotActiveException$sub_refs	java_io_NotActiveException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_NotActiveException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_NotActiveException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_NotActiveException$sub_nonrefs	java_io_NotActiveException;
};

// Object instance structure
struct _jc_java_io_NotActiveException$object {
	_jc_java_io_NotActiveException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_NotActiveException$vtype	*vtype;
	_jc_java_io_NotActiveException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_NotActiveException$vtype _jc_java_io_NotActiveException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_NotActiveException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_NotActiveException$class_object;

#endif	/* _JC_java_io_NotActiveException_H_ */

==> jc-1.4.6.tar.gz: java/io/NotActiveException.h <==
// public class java.io.NotActiveException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class a14ff42e403f5063 java_io_NotActiveException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_NotActiveException_H_
#define _JC_java_io_NotActiveException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_NotActiveException$sub_refs	_jc_java_io_NotActiveException$sub_refs;
typedef struct _jc_java_io_NotActiveException$sub_nonrefs	_jc_java_io_NotActiveException$sub_nonrefs;
typedef struct _jc_java_io_NotActiveException$refs	_jc_java_io_NotActiveException$refs;
typedef struct _jc_java_io_NotActiveException$nonrefs	_jc_java_io_NotActiveException$nonrefs;
typedef struct _jc_java_io_NotActiveException$object	_jc_java_io_NotActiveException$object;

typedef struct _jc_java_io_NotActiveException$fields_struct	_jc_java_io_NotActiveException$fields_struct;
typedef const struct _jc_java_io_NotActiveException$vmethods	_jc_java_io_NotActiveException$vmethods;
typedef const struct _jc_java_io_NotActiveException$vtable	_jc_java_io_NotActiveException$vtable;
typedef const struct _jc_java_io_NotActiveException$vtype	_jc_java_io_NotActiveException$vtype;

// Class fields structure
struct _jc_java_io_NotActiveException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_NotActiveException$fields_struct _jc_java_io_NotActiveException$class_fields;

// Constructors
extern void _jc_java_io_NotActiveException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_io_NotActiveException$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_NotActiveException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_io_NotActiveException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_NotActiveException$vmethods {
};

// Vtable
struct _jc_java_io_NotActiveException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_NotActiveException$vmethods	java_io_NotActiveException;
};

// Vtype
struct _jc_java_io_NotActiveException$vtype {
	_jc_type			type;
	_jc_java_io_NotActiveException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_NotActiveException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_NotActiveException$refs {
    _jc_java_io_NotActiveException$sub_refs	java_io_NotActiveException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_NotActiveException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_NotActiveException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_NotActiveException$sub_nonrefs	java_io_NotActiveException;
};

// Object instance structure
struct _jc_java_io_NotActiveException$object {
	_jc_java_io_NotActiveException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_NotActiveException$vtype	*vtype;
	_jc_java_io_NotActiveException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_NotActiveException$vtype _jc_java_io_NotActiveException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_NotActiveException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_NotActiveException$class_object;

#endif	/* _JC_java_io_NotActiveException_H_ */
